# -*- coding: utf-8 -*-
#
# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
#
# Copyright 2009 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
""" Tests for main.Main class """
import dbus
import shutil

from ubuntuone.syncdaemon.main import Main
from contrib.testing.testcase import (
    BaseTwistedTestCase,
)


class MainTests(BaseTwistedTestCase):
    """ Basic tests to check main.Main """

    def setUp(self):
        """ Sets up a test. """
        BaseTwistedTestCase.setUp(self)
        self.root = self.mktemp('root')
        self.shares = self.mktemp('shares')
        self.data = self.mktemp('data')
        # monkeypatch busName.__del__ to avoid errors on gc
        # we take care of releasing the name in shutdown
        dbus.service.BusName.__del__ = lambda _: None

    def tearDown(self):
        '''Clean up the tests.'''
        shutil.rmtree(self.root)
        shutil.rmtree(self.shares)
        shutil.rmtree(self.data)
        BaseTwistedTestCase.tearDown(self)

    def test_main_initialization(self):
        """test that creating a Main instance works as expected."""
        main = Main(self.root, self.shares, self.data,
                host='fake_host', port=0, dns_srv=False, ssl=False,
                disable_ssl_verify=True, realm='fake.realm', mark_interval=60)
        main.shutdown()

    def test_main_start(self):
        """test that Main.start works"""
        main = Main(self.root, self.shares, self.data,
                host='fake_host', port=0, dns_srv=False, ssl=False,
                disable_ssl_verify=True, realm='fake.realm', mark_interval=60)
        d = main.start()
        d.addCallbacks(lambda r: main.shutdown(),
                       lambda r: self.fail('Test failed: %r' % r))
        return d



